@@ -1,7 +1,10 @@
 import requests
+from logging import getLogger
 
 BASE_MINT_URL = "{faucet_url}/api/v1/mint"
 
+logger = getLogger(__name__)
+
 
 def mint(pub_key: str, asset: str, amount: int, faucet_url: str) -> None:
     url = BASE_MINT_URL.format(faucet_url=faucet_url)
@@ -11,4 +14,8 @@ def mint(pub_key: str, asset: str, amount: int, faucet_url: str) -> None:
         "asset": asset,
     }
     req = requests.post(url, json=payload)
-    req.raise_for_status()
+    try:
+        req.raise_for_status()
+    except Exception as e:
+        logger.exception(f"Exception in minting: {req.json()}")
+        raise e
