@@ -1,23 +1,24 @@
-import base64
 import json
 import logging
 from typing import Callable, Optional
 
-
+import vega_sim.api.data_raw as data_raw
 import vega_sim.grpc.client as vac
-import vega_sim.proto.data_node.api.v1 as data_node_protos
+import vega_sim.proto.data_node.api.v2 as data_node_protos_v2
+
 import vega_sim.proto.vega as vega_protos
-from vega_sim.proto.vega.commands.v1.commands_pb2 import ProposalSubmission
-import vega_sim.proto.vega.oracles.v1 as oracles_protos
 import vega_sim.proto.vega.commands.v1 as commands_protos
+import vega_sim.proto.vega.data.v1 as oracles_protos
+import vega_sim.proto.vega.data_source_pb2 as data_source_protos
+from vega_sim.api.data import find_asset_id
 from vega_sim.api.helpers import (
     ProposalNotAcceptedError,
+    enum_to_str,
     generate_id,
     wait_for_acceptance,
-    enum_to_str,
-    forward,
 )
-from vega_sim.api.data import find_asset_id
+from vega_sim.api.market import MarketConfig
+from vega_sim.proto.vega.commands.v1.commands_pb2 import ProposalSubmission
 from vega_sim.wallet.base import Wallet
 
 logger = logging.getLogger(__name__)
@@ -31,12 +32,13 @@ class LowBalanceError(Exception):
 
 def _proposal_loader(
     proposal_ref: str,
-    data_client: vac.VegaTradingDataClient,
+    data_client: vac.VegaTradingDataClientV2,
 ) -> bool:
-    request = data_node_protos.trading_data.GetProposalByReferenceRequest(
-        reference=proposal_ref
+    request = data_node_protos_v2.trading_data.GetGovernanceDataRequest(
+        reference=proposal_ref,
     )
-    return data_client.GetProposalByReference(request).data
+    response = data_client.GetGovernanceData(request)
+    return response.data
 
 
 def _default_risk_model() -> vega_protos.markets.LogNormalRiskModel:
@@ -64,20 +66,75 @@ def _default_price_monitoring_parameters() -> (
     )
 
 
-def get_blockchain_time(data_client: vac.VegaTradingDataClient) -> int:
+def get_blockchain_time(data_client: vac.VegaTradingDataClientV2) -> int:
     """Returns blockchain time in seconds since the epoch"""
     blockchain_time = data_client.GetVegaTime(
-        data_node_protos.trading_data.GetVegaTimeRequest()
+        data_node_protos_v2.trading_data.GetVegaTimeRequest()
     ).timestamp
     return int(blockchain_time / 1e9)
 
 
+def propose_market_from_config(
+    data_client: vac.VegaTradingDataClientV2,
+    wallet: Wallet,
+    proposal_wallet_name: str,
+    market_config: MarketConfig,
+    closing_time: str,
+    enactment_time: str,
+    time_forward_fn: Optional[Callable[[], None]] = None,
+    governance_asset: Optional[str] = "VOTE",
+    proposal_key_name: Optional[str] = None,
+) -> str:
+    # Make sure Vega network has governance asset
+    vote_asset_id = find_asset_id(
+        governance_asset, raise_on_missing=True, data_client=data_client
+    )
+    pub_key = wallet.public_key(proposal_wallet_name, proposal_key_name)
+
+    # Request accounts for party and check governance asset balance
+    party_accounts = data_raw.party_accounts(
+        data_client=data_client, asset_id=vote_asset_id, party_id=pub_key
+    )
+
+    voting_balance = 0
+    for account in party_accounts:
+        if account.asset == vote_asset_id:
+            voting_balance = account.balance
+            break
+
+    if voting_balance == 0:
+        raise LowBalanceError(
+            f"Public key {pub_key} is missing governance token {governance_asset}"
+        )
+
+    # Build NewMarketConfiguration proto
+    changes = market_config.build()
+
+    # Build ProposalTerms proto
+    proposal = _build_generic_proposal(
+        pub_key=pub_key,
+        data_client=data_client,
+        closing_time=closing_time,
+        enactment_time=enactment_time,
+    )
+    proposal.terms.new_market.CopyFrom(changes)
+
+    return _make_and_wait_for_proposal(
+        wallet=wallet,
+        wallet_name=proposal_wallet_name,
+        key_name=proposal_key_name,
+        proposal=proposal,
+        data_client=data_client,
+        time_forward_fn=time_forward_fn,
+    ).proposal.id
+
+
 def propose_future_market(
     market_name: str,
     wallet_name: str,
     wallet: Wallet,
     settlement_asset_id: str,
-    data_client: vac.VegaTradingDataClient,
+    data_client: vac.VegaTradingDataClientV2,
     termination_pub_key: str,
     governance_asset: str = "VOTE",
     future_asset: str = "BTC",
@@ -90,6 +147,7 @@ def propose_future_market(
     price_monitoring_parameters: Optional[
         vega_protos.markets.PriceMonitoringParameters
     ] = None,
+    key_name: Optional[str] = None,
 ) -> str:
     """Propose a future market as specified user.
 
@@ -105,7 +163,7 @@ def propose_future_market(
         settlement_asset_id:
             str, the asset id the market will use for settlement
         data_client:
-            VegaTradingDataClient, an instantiated gRPC client for interacting with the
+            VegaTradingDataClientV2, an instantiated gRPC client for interacting with the
                 Vega data node
         termination_pub_key:
             str, the public key of the oracle to be used for trading termination
@@ -126,6 +184,8 @@ def propose_future_market(
             PriceMonitoringParameters, A set of parameters determining when the market
                 will drop into a price auction. If not passed defaults to a very
                 permissive setup
+        key_name:
+            Optional[str], key name stored in metadata. Defaults to None.
 
     Returns:
         str, the ID of the future market proposal on chain
@@ -134,15 +194,12 @@ def propose_future_market(
     vote_asset_id = find_asset_id(
         governance_asset, raise_on_missing=True, data_client=data_client
     )
-    pub_key = wallet.public_key(wallet_name)
+    pub_key = wallet.public_key(wallet_name, key_name)
 
     # Request accounts for party and check governance asset balance
-
-    party_accounts = data_client.PartyAccounts(
-        data_node_protos.trading_data.PartyAccountsRequest(
-            party_id=pub_key, asset=vote_asset_id
-        )
-    ).accounts
+    party_accounts = data_raw.party_accounts(
+        data_client=data_client, asset_id=vote_asset_id, party_id=pub_key
+    )
 
     voting_balance = 0
     for account in party_accounts:
@@ -162,29 +219,45 @@ def propose_future_market(
         else _default_price_monitoring_parameters()
     )
 
-    oracle_spec_for_settlement_price = oracles_protos.spec.OracleSpecConfiguration(
-        pub_keys=[termination_pub_key],
-        filters=[
-            oracles_protos.spec.Filter(
-                key=oracles_protos.spec.PropertyKey(
-                    name=f"price.{future_asset}.value",
-                    type=oracles_protos.spec.PropertyKey.Type.TYPE_INTEGER,
-                ),
-                conditions=[],
+    data_source_spec_for_settlement_data = data_source_protos.DataSourceDefinition(
+        external=data_source_protos.DataSourceDefinitionExternal(
+            oracle=data_source_protos.DataSourceSpecConfiguration(
+                signers=[
+                    oracles_protos.data.Signer(
+                        pub_key=oracles_protos.data.PubKey(key=termination_pub_key)
+                    )
+                ],
+                filters=[
+                    oracles_protos.spec.Filter(
+                        key=oracles_protos.spec.PropertyKey(
+                            name=f"price.{future_asset}.value",
+                            type=oracles_protos.spec.PropertyKey.Type.TYPE_INTEGER,
+                        ),
+                        conditions=[],
+                    )
+                ],
             )
-        ],
+        )
     )
-    oracle_spec_for_trading_termination = oracles_protos.spec.OracleSpecConfiguration(
-        pub_keys=[termination_pub_key],
-        filters=[
-            oracles_protos.spec.Filter(
-                key=oracles_protos.spec.PropertyKey(
-                    name="trading.terminated",
-                    type=oracles_protos.spec.PropertyKey.Type.TYPE_BOOLEAN,
-                ),
-                conditions=[],
+    data_source_spec_for_trading_termination = data_source_protos.DataSourceDefinition(
+        external=data_source_protos.DataSourceDefinitionExternal(
+            oracle=data_source_protos.DataSourceSpecConfiguration(
+                signers=[
+                    oracles_protos.data.Signer(
+                        pub_key=oracles_protos.data.PubKey(key=termination_pub_key)
+                    )
+                ],
+                filters=[
+                    oracles_protos.spec.Filter(
+                        key=oracles_protos.spec.PropertyKey(
+                            name="trading.terminated",
+                            type=oracles_protos.spec.PropertyKey.Type.TYPE_BOOLEAN,
+                        ),
+                        conditions=[],
+                    )
+                ],
             )
-        ],
+        )
     )
 
     price_decimals = 5 if market_decimals is None else market_decimals
@@ -196,13 +269,13 @@ def propose_future_market(
                 future=vega_protos.governance.FutureProduct(
                     settlement_asset=settlement_asset_id,
                     quote_name=future_asset,
-                    oracle_spec_for_settlement_price=oracle_spec_for_settlement_price,
-                    oracle_spec_for_trading_termination=oracle_spec_for_trading_termination,
-                    oracle_spec_binding=vega_protos.markets.OracleSpecToFutureBinding(
-                        settlement_price_property=f"price.{future_asset}.value",
+                    data_source_spec_for_settlement_data=data_source_spec_for_settlement_data,
+                    data_source_spec_for_trading_termination=data_source_spec_for_trading_termination,
+                    data_source_spec_binding=vega_protos.markets.DataSourceSpecToFutureBinding(
+                        settlement_data_property=f"price.{future_asset}.value",
                         trading_termination_property="trading.terminated",
                     ),
-                    settlement_price_decimals=price_decimals,
+                    settlement_data_decimals=price_decimals,
                 ),
             ),
             decimal_places=price_decimals,
@@ -238,6 +311,7 @@ def propose_future_market(
         proposal=proposal,
         data_client=data_client,
         time_forward_fn=time_forward_fn,
+        key_name=key_name,
     ).proposal.id
 
 
@@ -248,11 +322,12 @@ def propose_network_parameter_change(
     wallet: Wallet,
     closing_time: Optional[int] = None,
     enactment_time: Optional[int] = None,
-    data_client: Optional[vac.VegaTradingDataClient] = None,
+    data_client: Optional[vac.VegaTradingDataClientV2] = None,
     time_forward_fn: Optional[Callable[[], None]] = None,
+    key_name: Optional[str] = None,
 ):
     network_param_update = _build_generic_proposal(
-        pub_key=wallet.public_key(wallet_name),
+        pub_key=wallet.public_key(wallet_name, key_name),
         data_client=data_client,
         closing_time=closing_time,
         enactment_time=enactment_time,
@@ -268,6 +343,7 @@ def propose_network_parameter_change(
         proposal=network_param_update,
         data_client=data_client,
         time_forward_fn=time_forward_fn,
+        key_name=key_name,
     ).proposal.id
 
 
@@ -278,11 +354,12 @@ def propose_market_update(
     market_update: vega_protos.governance.UpdateMarketConfiguration,
     closing_time: Optional[int] = None,
     enactment_time: Optional[int] = None,
-    data_client: Optional[vac.VegaTradingDataClient] = None,
+    data_client: Optional[vac.VegaTradingDataClientV2] = None,
     time_forward_fn: Optional[Callable[[], None]] = None,
+    key_name: Optional[str] = None,
 ) -> str:
     network_param_update = _build_generic_proposal(
-        pub_key=wallet.public_key(wallet_name),
+        pub_key=wallet.public_key(wallet_name, key_name),
         data_client=data_client,
         closing_time=closing_time,
         enactment_time=enactment_time,
@@ -304,6 +381,7 @@ def approve_proposal(
     wallet_name: str,
     proposal_id: str,
     wallet: Wallet,
+    key_name: Optional[str] = None,
 ):
     wallet.submit_transaction(
         transaction=commands_protos.commands.VoteSubmission(
@@ -311,6 +389,7 @@ def approve_proposal(
         ),
         name=wallet_name,
         transaction_type="vote_submission",
+        key_name=key_name,
     )
 
 
@@ -320,13 +399,14 @@ def propose_asset(
     name: str,
     symbol: str,
     decimals: int,
-    data_client: vac.VegaTradingDataClient,
+    data_client: vac.VegaTradingDataClientV2,
     quantum: int = 1,
     max_faucet_amount: int = 10e9,
     closing_time: Optional[int] = None,
     enactment_time: Optional[int] = None,
     validation_time: Optional[int] = None,
     time_forward_fn: Optional[Callable[[], None]] = None,
+    key_name: Optional[str] = None,
 ) -> str:
     asset_detail = vega_protos.assets.AssetDetails(
         name=name,
@@ -338,7 +418,7 @@ def propose_asset(
         ),
     )
     proposal = _build_generic_proposal(
-        pub_key=wallet.public_key(wallet_name),
+        pub_key=wallet.public_key(wallet_name, key_name),
         data_client=data_client,
         closing_time=closing_time,
         enactment_time=enactment_time,
@@ -358,12 +438,13 @@ def propose_asset(
         proposal=proposal,
         data_client=data_client,
         time_forward_fn=time_forward_fn,
+        key_name=key_name,
     ).proposal.id
 
 
 def _build_generic_proposal(
     pub_key: str,
-    data_client: vac.VegaTradingDataClient,
+    data_client: vac.VegaTradingDataClientV2,
     closing_time: Optional[int] = None,
     enactment_time: Optional[int] = None,
 ) -> commands_protos.commands.ProposalSubmission:
@@ -401,19 +482,31 @@ def _make_and_wait_for_proposal(
     wallet_name: str,
     wallet: Wallet,
     proposal: commands_protos.commands.ProposalSubmission,
-    data_client: vac.VegaTradingDataClient,
+    data_client: vac.VegaTradingDataClientV2,
     time_forward_fn: Optional[Callable[[], None]] = None,
+    key_name: Optional[str] = None,
 ) -> ProposalSubmission:
     wallet.submit_transaction(
-        transaction=proposal, name=wallet_name, transaction_type="proposal_submission"
+        transaction=proposal,
+        name=wallet_name,
+        transaction_type="proposal_submission",
+        key_name=key_name,
     )
     logger.debug("Waiting for proposal acceptance")
 
-    time_forward_fn()
-    proposal = wait_for_acceptance(
-        proposal.reference,
-        lambda p: _proposal_loader(p, data_client),
-    )
+    # Allow one failure, forward once more
+    try:
+        time_forward_fn()
+        proposal = wait_for_acceptance(
+            proposal.reference,
+            lambda p: _proposal_loader(p, data_client),
+        )
+    except ProposalNotAcceptedError:
+        time_forward_fn()
+        proposal = wait_for_acceptance(
+            proposal.reference,
+            lambda p: _proposal_loader(p, data_client),
+        )
 
     prop_state = enum_to_str(
         vega_protos.governance.Proposal.State, proposal.proposal.state
@@ -432,6 +525,7 @@ def settle_oracle(
     wallet: Wallet,
     settlement_price: float,
     oracle_name: str,
+    key_name: Optional[str] = None,
 ) -> None:
     """
     Settle the market and send settlement price.
@@ -447,6 +541,8 @@ def settle_oracle(
             float, final settlement price for the asset
         oracle_name:
             str, the name of the oracle to settle
+        key_name:
+            Optional[str], key name stored in metadata. Defaults to None.
 
     """
 
@@ -454,28 +550,30 @@ def settle_oracle(
     payload = {"trading.terminated": "true"}
     payload = json.dumps(payload).encode()
 
-    oracle_submission = commands_protos.oracles.OracleDataSubmission(
+    oracle_submission = commands_protos.data.OracleDataSubmission(
         payload=payload,
-        source=commands_protos.oracles.OracleDataSubmission.OracleSource.ORACLE_SOURCE_JSON,
+        source=commands_protos.data.OracleDataSubmission.OracleSource.ORACLE_SOURCE_JSON,
     )
 
     wallet.submit_transaction(
         transaction=oracle_submission,
         name=wallet_name,
         transaction_type="oracle_data_submission",
+        key_name=key_name,
     )
 
     # use oracle to settle market
     payload = {oracle_name: str(settlement_price)}
     payload = json.dumps(payload).encode()
 
-    oracle_submission = commands_protos.oracles.OracleDataSubmission(
+    oracle_submission = commands_protos.data.OracleDataSubmission(
         payload=payload,
-        source=commands_protos.oracles.OracleDataSubmission.OracleSource.ORACLE_SOURCE_JSON,
+        source=commands_protos.data.OracleDataSubmission.OracleSource.ORACLE_SOURCE_JSON,
     )
 
     wallet.submit_transaction(
         transaction=oracle_submission,
         name=wallet_name,
         transaction_type="oracle_data_submission",
+        key_name=key_name,
     )
