@@ -1,7 +1,7 @@
 from . import commands_pb2 as commands
 from . import commands_pb2_grpc as commands_grpc
-from . import oracles_pb2 as oracles
-from . import oracles_pb2_grpc as oracles_grpc
+from . import data_pb2 as data
+from . import data_pb2_grpc as data_grpc
 from . import signature_pb2 as signature
 from . import signature_pb2_grpc as signature_grpc
 from . import transaction_pb2 as transaction
@@ -12,8 +12,8 @@ from . import validator_commands_pb2_grpc as validator_commands_grpc
 __all__ = [
     "commands",
     "commands_grpc",
-    "oracles",
-    "oracles_grpc",
+    "data",
+    "data_grpc",
     "signature",
     "signature_grpc",
     "transaction",
