@@ -29,6 +29,9 @@ LIQUIDITY = WalletConfig("liquidity", "liquiditypass")
 # Terminate the market and send settlment price
 TERMINATE_WALLET = WalletConfig("terminate", "terminate")
 
+# informed trader wallet
+INFORMED_WALLET = WalletConfig("INFORMED", "INFORMEDpass")
+
 
 class OptimalMarketMaker(StateAgentWithWallet):
     def __init__(
@@ -146,11 +149,11 @@ class OptimalMarketMaker(StateAgentWithWallet):
         self.vega.wait_fn(5)
         self.vega.wait_for_total_catchup()
         # Get asset id
-        self.tdai_id = self.vega.find_asset_id(symbol=self.asset_name)
+        self.asset_id = self.vega.find_asset_id(symbol=self.asset_name)
         # Top up asset
         self.vega.mint(
             self.wallet_name,
-            asset=self.tdai_id,
+            asset=self.asset_id,
             amount=self.initial_asset_mint,
         )
         self.vega.wait_for_total_catchup()
@@ -159,20 +162,16 @@ class OptimalMarketMaker(StateAgentWithWallet):
         self.vega.create_simple_market(
             market_name=self.market_name,
             proposal_wallet=self.wallet_name,
-            settlement_asset_id=self.tdai_id,
+            settlement_asset_id=self.asset_id,
             termination_wallet=self.terminate_wallet_name,
             market_decimals=self.mdp,
             position_decimals=self.market_position_decimal,
             future_asset=self.asset_name,
         )
-        self.vega.wait_fn(5)
+        self.vega.wait_for_total_catchup()
 
         # Get market id
-        self.market_id = [
-            m.id
-            for m in self.vega.all_markets()
-            if m.tradable_instrument.instrument.name == self.market_name
-        ][0]
+        self.market_id = self.vega.find_market_id(name=self.market_name)
 
         vega.submit_liquidity(
             wallet_name=self.wallet_name,
@@ -329,11 +328,7 @@ class MarketOrderTrader(StateAgentWithWallet):
         super().initialise(vega=vega)
 
         # Get market id
-        self.market_id = [
-            m.id
-            for m in self.vega.all_markets()
-            if m.tradable_instrument.instrument.name == self.market_name
-        ][0]
+        self.market_id = self.vega.find_market_id(name=self.market_name)
 
         # Get asset id
         tDAI_id = self.vega.find_asset_id(symbol=self.asset_name)
@@ -403,11 +398,7 @@ class LimitOrderTrader(StateAgentWithWallet):
         # Initialise wallet
         super().initialise(vega=vega)
         # Get market id
-        self.market_id = [
-            m.id
-            for m in self.vega.all_markets()
-            if m.tradable_instrument.instrument.name == self.market_name
-        ][0]
+        self.market_id = self.vega.find_market_id(name=self.market_name)
 
         # Get asset id
         tDAI_id = self.vega.find_asset_id(symbol=self.asset_name)
@@ -565,11 +556,7 @@ class OpenAuctionPass(StateAgentWithWallet):
         # Initialise wallet
         super().initialise(vega=vega)
         # Get market id
-        self.market_id = [
-            m.id
-            for m in self.vega.all_markets()
-            if m.tradable_instrument.instrument.name == self.market_name
-        ][0]
+        self.market_id = self.vega.find_market_id(name=self.market_name)
 
         # Get asset id
         tDAI_id = self.vega.find_asset_id(symbol=self.asset_name)
@@ -638,11 +625,7 @@ class OptimalLiquidityProvider(StateAgentWithWallet):
         super().initialise(vega=vega)
 
         # Get market id
-        self.market_id = [
-            m.id
-            for m in self.vega.all_markets()
-            if m.tradable_instrument.instrument.name == self.market_name
-        ][0]
+        self.market_id = self.vega.find_market_id(name=self.market_name)
 
         # Get asset id
         tDAI_id = self.vega.find_asset_id(symbol=self.asset_name)
@@ -653,11 +636,11 @@ class OptimalLiquidityProvider(StateAgentWithWallet):
             amount=self.initial_asset_mint,
         )
         # Get asset id
-        self.tdai_id = self.vega.find_asset_id(symbol=self.asset_name)
+        self.asset_id = self.vega.find_asset_id(symbol=self.asset_name)
         # Top up asset
         self.vega.mint(
             self.wallet_name,
-            asset=self.tdai_id,
+            asset=self.asset_id,
             amount=self.initial_asset_mint,
         )
         self.vega.wait_for_total_catchup()
@@ -776,7 +759,7 @@ class InformedTrader(StateAgentWithWallet):
         market_name: str = None,
         asset_name: str = None,
         initial_asset_mint: float = 1e8,
-        proportion_taken: float = 0.5,
+        proportion_taken: float = 0.8,
         tag: str = "",
     ):
         super().__init__(wallet_name + str(tag), wallet_pass)
@@ -794,11 +777,7 @@ class InformedTrader(StateAgentWithWallet):
         super().initialise(vega=vega)
 
         # Get market id
-        self.market_id = [
-            m.id
-            for m in self.vega.all_markets()
-            if m.tradable_instrument.instrument.name == self.market_name
-        ][0]
+        self.market_id = self.vega.find_market_id(name=self.market_name)
 
         # Get asset id
         tDAI_id = self.vega.find_asset_id(symbol=self.asset_name)
